@@ -4,16 +4,17 @@
 #
 # License: GPL 3, see file LICENSE
 #
-# Version: 20220629202744
+# Version: 20220705170908
 
 from time import sleep, time
 
-from .Scrollkeeper import Scrollkeeper
 from .Message import RequestSwitchFunction
+from .Scrollkeeper import Scrollkeeper
 from .Throttle import Throttle
 
+
 class Script:
-    def __init__(self, scrollkeeper:Scrollkeeper):
+    def __init__(self, scrollkeeper: Scrollkeeper):
         self.scrollkeeper = scrollkeeper
 
     def wait(self, seconds):
@@ -27,7 +28,8 @@ class Script:
                 return True
             sleep(0.1)
         return False
-     # waitForSwitch(switchaddress, state, timeout=60)
+
+    # waitForSwitch(switchaddress, state, timeout=60)
 
     def setSwitch(self, address, thrown):
         msg1 = RequestSwitchFunction(address, thrown, True)
@@ -35,18 +37,9 @@ class Script:
         self.scrollkeeper.sendMessage(msg1)
         sleep(1.5)
         self.scrollkeeper.sendMessage(msg2)
-        
+
     def getThrottle(self, locaddress):
-        self.acquireLocomotive(locaddress)
-        return Throttle(self.scrollkeeper, locaddress)
-    
-     # acquireLocomotive(locaddress, timeout=60)
-     # setSpeed(locaddress, direction, speed:float, timeout=60)
-     # setFunction(locaddress, function, state, duration=0, timeout=60)
-     # powerOff
-     # powerOn
-     # aliases:
-     # lightOn
-     # soundOn
-     # whistle
-        
+        return self.scrollkeeper.getThrottle(locaddress)
+
+    # powerOff
+    # powerOn
